@@ -1,6 +1,10 @@
-## Thu Apr 30 10:50:58 2020
-## Original file Copyright © 2020 A.C. Guidoum, K. Boukhetala
+## Tue Mar  5 18:13:25 2024
+## Original file Copyright © 2024 A.C. Guidoum, K. Boukhetala
 ## This file is part of the R package Sim.DiffProc
+## Department of Mathematics and Computer Science, 
+## Faculty of Sciences and Technology, 
+## University of Tamanghasset
+## and
 ## Department of Probabilities & Statistics
 ## Faculty of Mathematics
 ## University of Science and Technology Houari Boumediene
@@ -50,9 +54,9 @@ MCM.sde.default <- function(model,statistic,R=100,time,exact=NULL,names=NULL,
 	        stop( " please use 't0 < time <= T'")
      if (any(level <= 0 | level >= 1) )  
 	        stop( " please use '0 < level < 1'")
-     if (class(model)=="bridgesde1d" | class(model)=="bridgesde2d" | class(model)=="bridgesde3d") 
+     if ("bridgesde1d" %in% class(model) | "bridgesde2d" %in% class(model) | "bridgesde3d" %in% class(model)) 
 	        stop("Not available for diffusion bridges")
-     if (class(model)!="snssde1d" & class(model)!="snssde2d" & class(model)!="snssde3d") 
+     if (!"snssde1d" %in% class(model) & !"snssde2d" %in% class(model) & !"snssde3d" %in% class(model)) 
 	        stop(" 'model' is not class of 'snssdekd', k=1,2,3. ")
      if (missing(parallel)) 
 	     parallel <- getOption("parallel", "no")
@@ -67,7 +71,7 @@ MCM.sde.default <- function(model,statistic,R=100,time,exact=NULL,names=NULL,
             ncpus <- 1L
         loadNamespace("parallel")
      }
-     if (class(model)=="snssde1d"){
+     if ("snssde1d" %in% class(model)){
        statistic <- match.fun(statistic)
        fn1d      <- function(x,...) statistic(x, ...)
        rand      <- matrix(0,nrow=R,ncol=model$M)
@@ -102,7 +106,7 @@ MCM.sde.default <- function(model,statistic,R=100,time,exact=NULL,names=NULL,
          }
         }
         Stat      <- do.call("cbind",lapply(1:R,function(i) fn1d(rand,i,...)))
-      }else if (class(model)=="snssde2d"){
+      }else if ("snssde2d" %in% class(model)){
        statistic <- match.fun(statistic)
        fn2d      <- function(x,...) statistic(x, ...)
        rand      <- matrix(0,nrow=2*R,ncol=model$M)
@@ -143,7 +147,7 @@ MCM.sde.default <- function(model,statistic,R=100,time,exact=NULL,names=NULL,
         rand1 <- list(x=rand[seq(1,2*R,by=2),],y=rand[seq(2,2*R,by=2),])
         rand2 <- lapply(1:R,function(i) data.frame(x=rand1$x[i,], y=rand1$y[i,]))
         Stat  <- do.call("cbind",lapply(1:R,function(i) fn2d(rand2[[i]],...)))
-      }else if (class(model)=="snssde3d"){
+      }else if ("snssde3d" %in% class(model)){
         statistic <- match.fun(statistic)
         fn3d      <- function(x,...) statistic(x, ...)
         rand      <- matrix(0,nrow=3*R,ncol=model$M)
