@@ -1,6 +1,10 @@
-## Thu Apr 30 10:50:58 2020
-## Original file Copyright © 2020 A.C. Guidoum, K. Boukhetala
+## Tue Mar  5 18:13:25 2024
+## Original file Copyright © 2024 A.C. Guidoum, K. Boukhetala
 ## This file is part of the R package Sim.DiffProc
+## Department of Mathematics and Computer Science, 
+## Faculty of Sciences and Technology, 
+## University of Tamanghasset
+## and
 ## Department of Probabilities & Statistics
 ## Faculty of Mathematics
 ## University of Science and Technology Houari Boumediene
@@ -190,14 +194,14 @@ TEX.sde.default <- function(object, ...)
      greek_env
     }
    # core function
-   if (class(object) == "data.frame"){
+   if ("data.frame" %in% class(object)){
     cat("%%% LaTeX table generated in R",strsplit(version[['version.string']], ' ')[[1]][3],"by TEX.sde() method",
         "\n")
     cat("%%% Copy and paste the following output in your LaTeX file",
         "\n\n")
     cat(knitr::kable(object, format = "latex",...),
         "\n")
-    }else if (class(object) == "MCM.sde"){
+    }else if ("MCM.sde" %in% class(object)){
     tab <- object$MC
     expr <- parse(text = rownames(tab))
     # greek_test <- as.list(c(mem_sde,mem_sde_tex,expr,
@@ -226,7 +230,7 @@ TEX.sde.default <- function(object, ...)
         "\n\n")
     cat(knitr::kable(tab, format = "latex", escape = FALSE,...),
         "\n")
-    }else if (class(object) == "expression"){
+    }else if ("expression" %in% class(object)){
     expr <- object
     names <- all.names(expr)
     symbol_list <- setNames(as.list(names), names)
@@ -276,7 +280,7 @@ TEX.sde.default <- function(object, ...)
     body <- c(body, paste("\\end{cases}"))
     body <- c(body, paste("\\end{equation}"))
     structure(body, class = "Latex")}
-    }else if (class(object) == "MEM.sde"){
+    }else if ("MEM.sde" %in% class(object)){
     if (object$dim==1){
     expr <- c(parse(text = deparse(object$Means)),parse(text = deparse(object$Var)))
     names <- all.names(expr)
@@ -314,10 +318,10 @@ TEX.sde.default <- function(object, ...)
    body <- c(body, paste("\\begin{equation}\\label{eq:}"))
    body <- c(body, paste("\\begin{cases}"))
    body <- c(body, paste("\\begin{split}"))
-   body <- c(body,paste("\\frac{d}{dt} m_{1}(t) ~&=",dm1,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} m_{2}(t) ~&=",dm2,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} S_{1}(t) ~&=",dS1,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} S_{2}(t) ~&=",dS2,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} m_{1}(t) &=",dm1,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} m_{2}(t) &=",dm2,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} S_{1}(t) &=",dS1,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} S_{2}(t) &=",dS2,"\\\\"))
    body <- c(body,paste("\\frac{d}{dt} C_{12}(t) &=",dC12))
    body <- c(body, paste("\\end{split}"))
    body <- c(body, paste("\\end{cases}"))
@@ -345,12 +349,12 @@ TEX.sde.default <- function(object, ...)
    body <- c(body, paste("\\begin{equation}\\label{eq:}"))
    body <- c(body, paste("\\begin{cases}"))
    body <- c(body, paste("\\begin{split}"))
-   body <- c(body,paste("\\frac{d}{dt} m_{1}(t) ~&=",dm1,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} m_{2}(t) ~&=",dm2,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} m_{3}(t) ~&=",dm3,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} S_{1}(t) ~&=",dS1,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} S_{2}(t) ~&=",dS2,"\\\\"))
-   body <- c(body,paste("\\frac{d}{dt} S_{3}(t) ~&=",dS3,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} m_{1}(t) &=",dm1,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} m_{2}(t) &=",dm2,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} m_{3}(t) &=",dm3,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} S_{1}(t) &=",dS1,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} S_{2}(t) &=",dS2,"\\\\"))
+   body <- c(body,paste("\\frac{d}{dt} S_{3}(t) &=",dS3,"\\\\"))
    body <- c(body,paste("\\frac{d}{dt} C_{12}(t) &=",dC12,"\\\\"))
    body <- c(body,paste("\\frac{d}{dt} C_{13}(t) &=",dC13,"\\\\"))
    body <- c(body,paste("\\frac{d}{dt} C_{23}(t) &=",dC23))
