@@ -1,6 +1,10 @@
-## Fri Apr 03 08:54:53 2020
-## Original file Copyright © 2020 A.C. Guidoum, K. Boukhetala
+## Tue Mar  5 18:13:25 2024
+## Original file Copyright © 2024 A.C. Guidoum, K. Boukhetala
 ## This file is part of the R package Sim.DiffProc
+## Department of Mathematics and Computer Science, 
+## Faculty of Sciences and Technology, 
+## University of Tamanghasset
+## and
 ## Department of Probabilities & Statistics
 ## Faculty of Mathematics
 ## University of Science and Technology Houari Boumediene
@@ -33,8 +37,8 @@ rsde1d <- function(object, ...)  UseMethod("rsde1d")
 
 rsde1d.default <- function(object,at,...)
                      {
-    if (class(object) == "snssde1d") {M=object$M}
-	else if (class(object) == "bridgesde1d") {M=length(na.omit(object$C))}
+    if ("snssde1d" %in% class(object)) {M=object$M}
+	else if ("bridgesde1d" %in% class(object)) {M=length(na.omit(object$C))}
     if (missing(at)) 
 	          at = as.numeric(object$T)
     if (any(as.numeric(object$T) < at || as.numeric(object$t0) > at) )  
@@ -59,8 +63,8 @@ rsde2d <- function(object, ...)  UseMethod("rsde2d")
 
 rsde2d.default <- function(object,at,...)
                     { 			
-	if (class(object) == "snssde2d") {M=object$M}
-	else if (class(object) == "bridgesde2d") {M=length(na.omit(object$Cx))}
+	if ("snssde2d" %in% class(object)) {M=object$M}
+	else if ("bridgesde2d" %in% class(object)) {M=length(na.omit(object$Cx))}
     if (missing(at)) 
 	        at = as.numeric(object$T)
     if (any(as.numeric(object$T) < at || as.numeric(object$t0) > at) )  
@@ -95,8 +99,8 @@ rsde3d <- function(object, ...)  UseMethod("rsde3d")
 
 rsde3d.default <- function(object,at,...)
                     { 
-	if (class(object) == "snssde3d") {M=object$M}
-	else if (class(object) == "bridgesde3d") {M=length(na.omit(object$Cx))}
+	if ("snssde3d" %in% class(object)) {M=object$M}
+	else if ("bridgesde3d" %in% class(object)) {M=length(na.omit(object$Cx))}
     if (missing(at)) 
 	         at = as.numeric(object$T)
     if (any(as.numeric(object$T) < at || as.numeric(object$t0) > at) )  
